---
title: <span class="badge object-type-scalar"></span> MilesPerHour
---
# <span class="badge object-type-scalar"></span> MilesPerHour

Velocity: miles/hour (mph)

## Definition

```python
# Velocity: miles/hour (mph)
MilesPerHour: typing.Literal["velocitymph"] = "velocitymph"
```
